@@ -19,6 +19,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
 import aws_cdk
@@ -51,6 +53,10 @@ class BastionAccessPolicy(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(BastionAccessPolicy.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = BastionAccessPolicyProps(security_tag=security_tag)
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -65,6 +71,9 @@ class BastionAccessPolicy(
 
     @policy.setter
     def policy(self, value: aws_cdk.aws_iam.PolicyDocument) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(BastionAccessPolicy, "policy").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "policy", value)
 
 
@@ -89,7 +98,7 @@ class BastionPermissionSet(
         managed_policies: typing.Optional[typing.Sequence[builtins.str]] = None,
         relay_state_type: typing.Optional[builtins.str] = None,
         session_duration: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Sequence[aws_cdk.CfnTag]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.CfnTag, typing.Dict[str, typing.Any]]]] = None,
         security_tag: typing.Optional[aws_cdk.Tag] = None,
     ) -> None:
         '''
@@ -107,6 +116,10 @@ class BastionPermissionSet(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(BastionPermissionSet.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = BastionPermissionSetProps(
             instance_arn=instance_arn,
             name=name,
@@ -135,6 +148,11 @@ class BastionPermissionSet(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(BastionPermissionSet.assign)
+            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
+            check_type(argname="argument principal_id", value=principal_id, expected_type=type_hints["principal_id"])
+            check_type(argname="argument principal_type", value=principal_type, expected_type=type_hints["principal_type"])
         return typing.cast(None, jsii.invoke(self, "assign", [account_id, principal_id, principal_type]))
 
     @builtins.property # type: ignore[misc]
@@ -147,6 +165,9 @@ class BastionPermissionSet(
 
     @security_tag.setter
     def security_tag(self, value: aws_cdk.Tag) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(BastionPermissionSet, "security_tag").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "securityTag", value)
 
 
@@ -168,8 +189,8 @@ class LinuxBastion(
         package_manager: typing.Optional["LinuxPackageManager"] = None,
         packages: typing.Optional[typing.Sequence[builtins.str]] = None,
         vpc: aws_cdk.aws_ec2.IVpc,
-        vpc_subnets: aws_cdk.aws_ec2.SubnetSelection,
-        block_devices: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.BlockDevice]] = None,
+        vpc_subnets: typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]],
+        block_devices: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_ec2.BlockDevice, typing.Dict[str, typing.Any]]]] = None,
         instance_name: typing.Optional[builtins.str] = None,
         instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
         machine_image: typing.Optional[aws_cdk.aws_ec2.IMachineImage] = None,
@@ -198,6 +219,10 @@ class LinuxBastion(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LinuxBastion.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = LinuxBastionProps(
             package_manager=package_manager,
             packages=packages,
@@ -356,6 +381,10 @@ class ScheduleShutdown(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ScheduleShutdown.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ScheduleShutdownProps(
             shutdown_schedule=shutdown_schedule,
             timezone=timezone,
@@ -377,6 +406,9 @@ class SecurityTagable:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SecurityTagable.__init__)
+            check_type(argname="argument security_tag", value=security_tag, expected_type=type_hints["security_tag"])
         self._values: typing.Dict[str, typing.Any] = {}
         if security_tag is not None:
             self._values["security_tag"] = security_tag
@@ -420,8 +452,8 @@ class WindowsBastion(
         create_key_pair: typing.Optional[builtins.bool] = None,
         windows_packages: typing.Optional[typing.Sequence[builtins.str]] = None,
         vpc: aws_cdk.aws_ec2.IVpc,
-        vpc_subnets: aws_cdk.aws_ec2.SubnetSelection,
-        block_devices: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.BlockDevice]] = None,
+        vpc_subnets: typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]],
+        block_devices: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_ec2.BlockDevice, typing.Dict[str, typing.Any]]]] = None,
         instance_name: typing.Optional[builtins.str] = None,
         instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
         machine_image: typing.Optional[aws_cdk.aws_ec2.IMachineImage] = None,
@@ -450,6 +482,10 @@ class WindowsBastion(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(WindowsBastion.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = WindowsBastionProps(
             create_key_pair=create_key_pair,
             windows_packages=windows_packages,
@@ -573,6 +609,9 @@ class BastionAccessPolicyProps(SecurityTagable):
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(BastionAccessPolicyProps.__init__)
+            check_type(argname="argument security_tag", value=security_tag, expected_type=type_hints["security_tag"])
         self._values: typing.Dict[str, typing.Any] = {}
         if security_tag is not None:
             self._values["security_tag"] = security_tag
@@ -621,8 +660,8 @@ class BastionInstanceProps(SecurityTagable):
         *,
         security_tag: typing.Optional[aws_cdk.Tag] = None,
         vpc: aws_cdk.aws_ec2.IVpc,
-        vpc_subnets: aws_cdk.aws_ec2.SubnetSelection,
-        block_devices: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.BlockDevice]] = None,
+        vpc_subnets: typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]],
+        block_devices: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_ec2.BlockDevice, typing.Dict[str, typing.Any]]]] = None,
         instance_name: typing.Optional[builtins.str] = None,
         instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
         machine_image: typing.Optional[aws_cdk.aws_ec2.IMachineImage] = None,
@@ -648,6 +687,19 @@ class BastionInstanceProps(SecurityTagable):
         '''
         if isinstance(vpc_subnets, dict):
             vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
+        if __debug__:
+            type_hints = typing.get_type_hints(BastionInstanceProps.__init__)
+            check_type(argname="argument security_tag", value=security_tag, expected_type=type_hints["security_tag"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument vpc_subnets", value=vpc_subnets, expected_type=type_hints["vpc_subnets"])
+            check_type(argname="argument block_devices", value=block_devices, expected_type=type_hints["block_devices"])
+            check_type(argname="argument instance_name", value=instance_name, expected_type=type_hints["instance_name"])
+            check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
+            check_type(argname="argument machine_image", value=machine_image, expected_type=type_hints["machine_image"])
+            check_type(argname="argument private_ip_address", value=private_ip_address, expected_type=type_hints["private_ip_address"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument security_group", value=security_group, expected_type=type_hints["security_group"])
+            check_type(argname="argument user_data", value=user_data, expected_type=type_hints["user_data"])
         self._values: typing.Dict[str, typing.Any] = {
             "vpc": vpc,
             "vpc_subnets": vpc_subnets,
@@ -836,7 +888,7 @@ class BastionPermissionSetProps(
         managed_policies: typing.Optional[typing.Sequence[builtins.str]] = None,
         relay_state_type: typing.Optional[builtins.str] = None,
         session_duration: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Sequence[aws_cdk.CfnTag]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.CfnTag, typing.Dict[str, typing.Any]]]] = None,
         security_tag: typing.Optional[aws_cdk.Tag] = None,
     ) -> None:
         '''
@@ -852,6 +904,17 @@ class BastionPermissionSetProps(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(BastionPermissionSetProps.__init__)
+            check_type(argname="argument instance_arn", value=instance_arn, expected_type=type_hints["instance_arn"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument inline_policy", value=inline_policy, expected_type=type_hints["inline_policy"])
+            check_type(argname="argument managed_policies", value=managed_policies, expected_type=type_hints["managed_policies"])
+            check_type(argname="argument relay_state_type", value=relay_state_type, expected_type=type_hints["relay_state_type"])
+            check_type(argname="argument session_duration", value=session_duration, expected_type=type_hints["session_duration"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
+            check_type(argname="argument security_tag", value=security_tag, expected_type=type_hints["security_tag"])
         self._values: typing.Dict[str, typing.Any] = {
             "instance_arn": instance_arn,
             "name": name,
@@ -993,8 +1056,8 @@ class LinuxBastionProps(BastionInstanceProps):
         *,
         security_tag: typing.Optional[aws_cdk.Tag] = None,
         vpc: aws_cdk.aws_ec2.IVpc,
-        vpc_subnets: aws_cdk.aws_ec2.SubnetSelection,
-        block_devices: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.BlockDevice]] = None,
+        vpc_subnets: typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]],
+        block_devices: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_ec2.BlockDevice, typing.Dict[str, typing.Any]]]] = None,
         instance_name: typing.Optional[builtins.str] = None,
         instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
         machine_image: typing.Optional[aws_cdk.aws_ec2.IMachineImage] = None,
@@ -1024,6 +1087,21 @@ class LinuxBastionProps(BastionInstanceProps):
         '''
         if isinstance(vpc_subnets, dict):
             vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
+        if __debug__:
+            type_hints = typing.get_type_hints(LinuxBastionProps.__init__)
+            check_type(argname="argument security_tag", value=security_tag, expected_type=type_hints["security_tag"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument vpc_subnets", value=vpc_subnets, expected_type=type_hints["vpc_subnets"])
+            check_type(argname="argument block_devices", value=block_devices, expected_type=type_hints["block_devices"])
+            check_type(argname="argument instance_name", value=instance_name, expected_type=type_hints["instance_name"])
+            check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
+            check_type(argname="argument machine_image", value=machine_image, expected_type=type_hints["machine_image"])
+            check_type(argname="argument private_ip_address", value=private_ip_address, expected_type=type_hints["private_ip_address"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument security_group", value=security_group, expected_type=type_hints["security_group"])
+            check_type(argname="argument user_data", value=user_data, expected_type=type_hints["user_data"])
+            check_type(argname="argument package_manager", value=package_manager, expected_type=type_hints["package_manager"])
+            check_type(argname="argument packages", value=packages, expected_type=type_hints["packages"])
         self._values: typing.Dict[str, typing.Any] = {
             "vpc": vpc,
             "vpc_subnets": vpc_subnets,
@@ -1231,6 +1309,11 @@ class ScheduleShutdownProps(SecurityTagable):
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ScheduleShutdownProps.__init__)
+            check_type(argname="argument security_tag", value=security_tag, expected_type=type_hints["security_tag"])
+            check_type(argname="argument shutdown_schedule", value=shutdown_schedule, expected_type=type_hints["shutdown_schedule"])
+            check_type(argname="argument timezone", value=timezone, expected_type=type_hints["timezone"])
         self._values: typing.Dict[str, typing.Any] = {}
         if security_tag is not None:
             self._values["security_tag"] = security_tag
@@ -1301,8 +1384,8 @@ class WindowsBastionProps(BastionInstanceProps):
         *,
         security_tag: typing.Optional[aws_cdk.Tag] = None,
         vpc: aws_cdk.aws_ec2.IVpc,
-        vpc_subnets: aws_cdk.aws_ec2.SubnetSelection,
-        block_devices: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.BlockDevice]] = None,
+        vpc_subnets: typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]],
+        block_devices: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_ec2.BlockDevice, typing.Dict[str, typing.Any]]]] = None,
         instance_name: typing.Optional[builtins.str] = None,
         instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
         machine_image: typing.Optional[aws_cdk.aws_ec2.IMachineImage] = None,
@@ -1332,6 +1415,21 @@ class WindowsBastionProps(BastionInstanceProps):
         '''
         if isinstance(vpc_subnets, dict):
             vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
+        if __debug__:
+            type_hints = typing.get_type_hints(WindowsBastionProps.__init__)
+            check_type(argname="argument security_tag", value=security_tag, expected_type=type_hints["security_tag"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument vpc_subnets", value=vpc_subnets, expected_type=type_hints["vpc_subnets"])
+            check_type(argname="argument block_devices", value=block_devices, expected_type=type_hints["block_devices"])
+            check_type(argname="argument instance_name", value=instance_name, expected_type=type_hints["instance_name"])
+            check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
+            check_type(argname="argument machine_image", value=machine_image, expected_type=type_hints["machine_image"])
+            check_type(argname="argument private_ip_address", value=private_ip_address, expected_type=type_hints["private_ip_address"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument security_group", value=security_group, expected_type=type_hints["security_group"])
+            check_type(argname="argument user_data", value=user_data, expected_type=type_hints["user_data"])
+            check_type(argname="argument create_key_pair", value=create_key_pair, expected_type=type_hints["create_key_pair"])
+            check_type(argname="argument windows_packages", value=windows_packages, expected_type=type_hints["windows_packages"])
         self._values: typing.Dict[str, typing.Any] = {
             "vpc": vpc,
             "vpc_subnets": vpc_subnets,
